# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Response(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Response - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'int',
            'libraries': 'list[DomainEntityRef]',
            'texts': 'list[ResponseText]',
            'created_by': 'User',
            'date_created': 'datetime',
            'interaction_type': 'str',
            'substitutions': 'list[ResponseSubstitution]',
            'substitutions_schema': 'JsonSchemaDocument',
            'response_type': 'str',
            'messaging_template': 'MessagingTemplate',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'libraries': 'libraries',
            'texts': 'texts',
            'created_by': 'createdBy',
            'date_created': 'dateCreated',
            'interaction_type': 'interactionType',
            'substitutions': 'substitutions',
            'substitutions_schema': 'substitutionsSchema',
            'response_type': 'responseType',
            'messaging_template': 'messagingTemplate',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._version = None
        self._libraries = None
        self._texts = None
        self._created_by = None
        self._date_created = None
        self._interaction_type = None
        self._substitutions = None
        self._substitutions_schema = None
        self._response_type = None
        self._messaging_template = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Response.
        The globally unique identifier for the object.

        :return: The id of this Response.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Response.
        The globally unique identifier for the object.

        :param id: The id of this Response.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Response.


        :return: The name of this Response.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Response.


        :param name: The name of this Response.
        :type: str
        """
        
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this Response.
        Version number required for updates.

        :return: The version of this Response.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Response.
        Version number required for updates.

        :param version: The version of this Response.
        :type: int
        """
        
        self._version = version

    @property
    def libraries(self):
        """
        Gets the libraries of this Response.
        One or more libraries response is associated with.

        :return: The libraries of this Response.
        :rtype: list[DomainEntityRef]
        """
        return self._libraries

    @libraries.setter
    def libraries(self, libraries):
        """
        Sets the libraries of this Response.
        One or more libraries response is associated with.

        :param libraries: The libraries of this Response.
        :type: list[DomainEntityRef]
        """
        
        self._libraries = libraries

    @property
    def texts(self):
        """
        Gets the texts of this Response.
        One or more texts associated with the response.

        :return: The texts of this Response.
        :rtype: list[ResponseText]
        """
        return self._texts

    @texts.setter
    def texts(self, texts):
        """
        Sets the texts of this Response.
        One or more texts associated with the response.

        :param texts: The texts of this Response.
        :type: list[ResponseText]
        """
        
        self._texts = texts

    @property
    def created_by(self):
        """
        Gets the created_by of this Response.
        User that created the response

        :return: The created_by of this Response.
        :rtype: User
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this Response.
        User that created the response

        :param created_by: The created_by of this Response.
        :type: User
        """
        
        self._created_by = created_by

    @property
    def date_created(self):
        """
        Gets the date_created of this Response.
        The date and time the response was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this Response.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Response.
        The date and time the response was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this Response.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def interaction_type(self):
        """
        Gets the interaction_type of this Response.
        The interaction type for this response.

        :return: The interaction_type of this Response.
        :rtype: str
        """
        return self._interaction_type

    @interaction_type.setter
    def interaction_type(self, interaction_type):
        """
        Sets the interaction_type of this Response.
        The interaction type for this response.

        :param interaction_type: The interaction_type of this Response.
        :type: str
        """
        allowed_values = ["chat", "email", "twitter"]
        if interaction_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for interaction_type -> " + interaction_type)
            self._interaction_type = "outdated_sdk_version"
        else:
            self._interaction_type = interaction_type

    @property
    def substitutions(self):
        """
        Gets the substitutions of this Response.
        Details about any text substitutions used in the texts for this response.

        :return: The substitutions of this Response.
        :rtype: list[ResponseSubstitution]
        """
        return self._substitutions

    @substitutions.setter
    def substitutions(self, substitutions):
        """
        Sets the substitutions of this Response.
        Details about any text substitutions used in the texts for this response.

        :param substitutions: The substitutions of this Response.
        :type: list[ResponseSubstitution]
        """
        
        self._substitutions = substitutions

    @property
    def substitutions_schema(self):
        """
        Gets the substitutions_schema of this Response.
        Metadata about the text substitutions in json schema format.

        :return: The substitutions_schema of this Response.
        :rtype: JsonSchemaDocument
        """
        return self._substitutions_schema

    @substitutions_schema.setter
    def substitutions_schema(self, substitutions_schema):
        """
        Sets the substitutions_schema of this Response.
        Metadata about the text substitutions in json schema format.

        :param substitutions_schema: The substitutions_schema of this Response.
        :type: JsonSchemaDocument
        """
        
        self._substitutions_schema = substitutions_schema

    @property
    def response_type(self):
        """
        Gets the response_type of this Response.
        The response type represented by the response.

        :return: The response_type of this Response.
        :rtype: str
        """
        return self._response_type

    @response_type.setter
    def response_type(self, response_type):
        """
        Sets the response_type of this Response.
        The response type represented by the response.

        :param response_type: The response_type of this Response.
        :type: str
        """
        allowed_values = ["MessagingTemplate", "CampaignSmsTemplate", "CampaignEmailTemplate"]
        if response_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for response_type -> " + response_type)
            self._response_type = "outdated_sdk_version"
        else:
            self._response_type = response_type

    @property
    def messaging_template(self):
        """
        Gets the messaging_template of this Response.
        An optional messaging template definition for responseType.MessagingTemplate.

        :return: The messaging_template of this Response.
        :rtype: MessagingTemplate
        """
        return self._messaging_template

    @messaging_template.setter
    def messaging_template(self, messaging_template):
        """
        Sets the messaging_template of this Response.
        An optional messaging template definition for responseType.MessagingTemplate.

        :param messaging_template: The messaging_template of this Response.
        :type: MessagingTemplate
        """
        
        self._messaging_template = messaging_template

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Response.
        The URI for this object

        :return: The self_uri of this Response.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Response.
        The URI for this object

        :param self_uri: The self_uri of this Response.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class VoicemailOrganizationPolicy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoicemailOrganizationPolicy - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'enabled': 'bool',
            'alert_timeout_seconds': 'int',
            'pin_configuration': 'PINConfiguration',
            'voicemail_extension': 'str',
            'pin_required': 'bool',
            'send_email_notifications': 'bool',
            'modified_date': 'datetime'
        }

        self.attribute_map = {
            'enabled': 'enabled',
            'alert_timeout_seconds': 'alertTimeoutSeconds',
            'pin_configuration': 'pinConfiguration',
            'voicemail_extension': 'voicemailExtension',
            'pin_required': 'pinRequired',
            'send_email_notifications': 'sendEmailNotifications',
            'modified_date': 'modifiedDate'
        }

        self._enabled = None
        self._alert_timeout_seconds = None
        self._pin_configuration = None
        self._voicemail_extension = None
        self._pin_required = None
        self._send_email_notifications = None
        self._modified_date = None

    @property
    def enabled(self):
        """
        Gets the enabled of this VoicemailOrganizationPolicy.
        Whether voicemail is enable for this organization

        :return: The enabled of this VoicemailOrganizationPolicy.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this VoicemailOrganizationPolicy.
        Whether voicemail is enable for this organization

        :param enabled: The enabled of this VoicemailOrganizationPolicy.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def alert_timeout_seconds(self):
        """
        Gets the alert_timeout_seconds of this VoicemailOrganizationPolicy.
        The organization's default number of seconds to ring a user's phone before a call is transfered to voicemail

        :return: The alert_timeout_seconds of this VoicemailOrganizationPolicy.
        :rtype: int
        """
        return self._alert_timeout_seconds

    @alert_timeout_seconds.setter
    def alert_timeout_seconds(self, alert_timeout_seconds):
        """
        Sets the alert_timeout_seconds of this VoicemailOrganizationPolicy.
        The organization's default number of seconds to ring a user's phone before a call is transfered to voicemail

        :param alert_timeout_seconds: The alert_timeout_seconds of this VoicemailOrganizationPolicy.
        :type: int
        """
        
        self._alert_timeout_seconds = alert_timeout_seconds

    @property
    def pin_configuration(self):
        """
        Gets the pin_configuration of this VoicemailOrganizationPolicy.
        The configuration for user PINs to access their voicemail from a phone

        :return: The pin_configuration of this VoicemailOrganizationPolicy.
        :rtype: PINConfiguration
        """
        return self._pin_configuration

    @pin_configuration.setter
    def pin_configuration(self, pin_configuration):
        """
        Sets the pin_configuration of this VoicemailOrganizationPolicy.
        The configuration for user PINs to access their voicemail from a phone

        :param pin_configuration: The pin_configuration of this VoicemailOrganizationPolicy.
        :type: PINConfiguration
        """
        
        self._pin_configuration = pin_configuration

    @property
    def voicemail_extension(self):
        """
        Gets the voicemail_extension of this VoicemailOrganizationPolicy.
        The extension for voicemail retrieval.  The default value is *86.

        :return: The voicemail_extension of this VoicemailOrganizationPolicy.
        :rtype: str
        """
        return self._voicemail_extension

    @voicemail_extension.setter
    def voicemail_extension(self, voicemail_extension):
        """
        Sets the voicemail_extension of this VoicemailOrganizationPolicy.
        The extension for voicemail retrieval.  The default value is *86.

        :param voicemail_extension: The voicemail_extension of this VoicemailOrganizationPolicy.
        :type: str
        """
        
        self._voicemail_extension = voicemail_extension

    @property
    def pin_required(self):
        """
        Gets the pin_required of this VoicemailOrganizationPolicy.
        If this is true, a PIN is required when accessing a user's voicemail from a phone.

        :return: The pin_required of this VoicemailOrganizationPolicy.
        :rtype: bool
        """
        return self._pin_required

    @pin_required.setter
    def pin_required(self, pin_required):
        """
        Sets the pin_required of this VoicemailOrganizationPolicy.
        If this is true, a PIN is required when accessing a user's voicemail from a phone.

        :param pin_required: The pin_required of this VoicemailOrganizationPolicy.
        :type: bool
        """
        
        self._pin_required = pin_required

    @property
    def send_email_notifications(self):
        """
        Gets the send_email_notifications of this VoicemailOrganizationPolicy.
        Whether email notifications are sent for new voicemails in the organization. If false, new voicemail email notifications are not be sent for the organization overriding any user or group setting.

        :return: The send_email_notifications of this VoicemailOrganizationPolicy.
        :rtype: bool
        """
        return self._send_email_notifications

    @send_email_notifications.setter
    def send_email_notifications(self, send_email_notifications):
        """
        Sets the send_email_notifications of this VoicemailOrganizationPolicy.
        Whether email notifications are sent for new voicemails in the organization. If false, new voicemail email notifications are not be sent for the organization overriding any user or group setting.

        :param send_email_notifications: The send_email_notifications of this VoicemailOrganizationPolicy.
        :type: bool
        """
        
        self._send_email_notifications = send_email_notifications

    @property
    def modified_date(self):
        """
        Gets the modified_date of this VoicemailOrganizationPolicy.
        The date the policy was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The modified_date of this VoicemailOrganizationPolicy.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this VoicemailOrganizationPolicy.
        The date the policy was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param modified_date: The modified_date of this VoicemailOrganizationPolicy.
        :type: datetime
        """
        
        self._modified_date = modified_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ContentGeneric(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContentGeneric - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'title': 'str',
            'description': 'str',
            'image': 'str',
            'video': 'str',
            'actions': 'ContentActions',
            'components': 'list[ButtonComponent]'
        }

        self.attribute_map = {
            'id': 'id',
            'title': 'title',
            'description': 'description',
            'image': 'image',
            'video': 'video',
            'actions': 'actions',
            'components': 'components'
        }

        self._id = None
        self._title = None
        self._description = None
        self._image = None
        self._video = None
        self._actions = None
        self._components = None

    @property
    def id(self):
        """
        Gets the id of this ContentGeneric.
        An ID assigned to this rich message content. Each instance inside the content array has a unique ID.

        :return: The id of this ContentGeneric.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ContentGeneric.
        An ID assigned to this rich message content. Each instance inside the content array has a unique ID.

        :param id: The id of this ContentGeneric.
        :type: str
        """
        
        self._id = id

    @property
    def title(self):
        """
        Gets the title of this ContentGeneric.
        Text to show in the title row

        :return: The title of this ContentGeneric.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this ContentGeneric.
        Text to show in the title row

        :param title: The title of this ContentGeneric.
        :type: str
        """
        
        self._title = title

    @property
    def description(self):
        """
        Gets the description of this ContentGeneric.
        Text to show in the description row. This is immediately below the title

        :return: The description of this ContentGeneric.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ContentGeneric.
        Text to show in the description row. This is immediately below the title

        :param description: The description of this ContentGeneric.
        :type: str
        """
        
        self._description = description

    @property
    def image(self):
        """
        Gets the image of this ContentGeneric.
        Path or URI to an image file

        :return: The image of this ContentGeneric.
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """
        Sets the image of this ContentGeneric.
        Path or URI to an image file

        :param image: The image of this ContentGeneric.
        :type: str
        """
        
        self._image = image

    @property
    def video(self):
        """
        Gets the video of this ContentGeneric.
        Path or URI to a video file

        :return: The video of this ContentGeneric.
        :rtype: str
        """
        return self._video

    @video.setter
    def video(self, video):
        """
        Sets the video of this ContentGeneric.
        Path or URI to a video file

        :param video: The video of this ContentGeneric.
        :type: str
        """
        
        self._video = video

    @property
    def actions(self):
        """
        Gets the actions of this ContentGeneric.
        User actions available on the content. All actions are optional and all actions are executed simultaneously.

        :return: The actions of this ContentGeneric.
        :rtype: ContentActions
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """
        Sets the actions of this ContentGeneric.
        User actions available on the content. All actions are optional and all actions are executed simultaneously.

        :param actions: The actions of this ContentGeneric.
        :type: ContentActions
        """
        
        self._actions = actions

    @property
    def components(self):
        """
        Gets the components of this ContentGeneric.
        An array of component objects

        :return: The components of this ContentGeneric.
        :rtype: list[ButtonComponent]
        """
        return self._components

    @components.setter
    def components(self, components):
        """
        Sets the components of this ContentGeneric.
        An array of component objects

        :param components: The components of this ContentGeneric.
        :type: list[ButtonComponent]
        """
        
        self._components = components

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationSocialExpressionEventTopicAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationSocialExpressionEventTopicAddress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'name_raw': 'str',
            'address_normalized': 'str',
            'address_raw': 'str',
            'address_displayable': 'str',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'name': 'name',
            'name_raw': 'nameRaw',
            'address_normalized': 'addressNormalized',
            'address_raw': 'addressRaw',
            'address_displayable': 'addressDisplayable',
            'additional_properties': 'additionalProperties'
        }

        self._name = None
        self._name_raw = None
        self._address_normalized = None
        self._address_raw = None
        self._address_displayable = None
        self._additional_properties = None

    @property
    def name(self):
        """
        Gets the name of this QueueConversationSocialExpressionEventTopicAddress.


        :return: The name of this QueueConversationSocialExpressionEventTopicAddress.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QueueConversationSocialExpressionEventTopicAddress.


        :param name: The name of this QueueConversationSocialExpressionEventTopicAddress.
        :type: str
        """
        
        self._name = name

    @property
    def name_raw(self):
        """
        Gets the name_raw of this QueueConversationSocialExpressionEventTopicAddress.


        :return: The name_raw of this QueueConversationSocialExpressionEventTopicAddress.
        :rtype: str
        """
        return self._name_raw

    @name_raw.setter
    def name_raw(self, name_raw):
        """
        Sets the name_raw of this QueueConversationSocialExpressionEventTopicAddress.


        :param name_raw: The name_raw of this QueueConversationSocialExpressionEventTopicAddress.
        :type: str
        """
        
        self._name_raw = name_raw

    @property
    def address_normalized(self):
        """
        Gets the address_normalized of this QueueConversationSocialExpressionEventTopicAddress.


        :return: The address_normalized of this QueueConversationSocialExpressionEventTopicAddress.
        :rtype: str
        """
        return self._address_normalized

    @address_normalized.setter
    def address_normalized(self, address_normalized):
        """
        Sets the address_normalized of this QueueConversationSocialExpressionEventTopicAddress.


        :param address_normalized: The address_normalized of this QueueConversationSocialExpressionEventTopicAddress.
        :type: str
        """
        
        self._address_normalized = address_normalized

    @property
    def address_raw(self):
        """
        Gets the address_raw of this QueueConversationSocialExpressionEventTopicAddress.


        :return: The address_raw of this QueueConversationSocialExpressionEventTopicAddress.
        :rtype: str
        """
        return self._address_raw

    @address_raw.setter
    def address_raw(self, address_raw):
        """
        Sets the address_raw of this QueueConversationSocialExpressionEventTopicAddress.


        :param address_raw: The address_raw of this QueueConversationSocialExpressionEventTopicAddress.
        :type: str
        """
        
        self._address_raw = address_raw

    @property
    def address_displayable(self):
        """
        Gets the address_displayable of this QueueConversationSocialExpressionEventTopicAddress.


        :return: The address_displayable of this QueueConversationSocialExpressionEventTopicAddress.
        :rtype: str
        """
        return self._address_displayable

    @address_displayable.setter
    def address_displayable(self, address_displayable):
        """
        Sets the address_displayable of this QueueConversationSocialExpressionEventTopicAddress.


        :param address_displayable: The address_displayable of this QueueConversationSocialExpressionEventTopicAddress.
        :type: str
        """
        
        self._address_displayable = address_displayable

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationSocialExpressionEventTopicAddress.


        :return: The additional_properties of this QueueConversationSocialExpressionEventTopicAddress.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationSocialExpressionEventTopicAddress.


        :param additional_properties: The additional_properties of this QueueConversationSocialExpressionEventTopicAddress.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UpdateWorkPlanRotationAgentRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UpdateWorkPlanRotationAgentRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'user_id': 'str',
            'date_range': 'DateRangeWithOptionalEnd',
            'position': 'int',
            'delete': 'bool'
        }

        self.attribute_map = {
            'user_id': 'userId',
            'date_range': 'dateRange',
            'position': 'position',
            'delete': 'delete'
        }

        self._user_id = None
        self._date_range = None
        self._position = None
        self._delete = None

    @property
    def user_id(self):
        """
        Gets the user_id of this UpdateWorkPlanRotationAgentRequest.
        The ID of an agent in this work plan rotation

        :return: The user_id of this UpdateWorkPlanRotationAgentRequest.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this UpdateWorkPlanRotationAgentRequest.
        The ID of an agent in this work plan rotation

        :param user_id: The user_id of this UpdateWorkPlanRotationAgentRequest.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def date_range(self):
        """
        Gets the date_range of this UpdateWorkPlanRotationAgentRequest.
        The date range to which this agent is effective in the work plan rotation

        :return: The date_range of this UpdateWorkPlanRotationAgentRequest.
        :rtype: DateRangeWithOptionalEnd
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """
        Sets the date_range of this UpdateWorkPlanRotationAgentRequest.
        The date range to which this agent is effective in the work plan rotation

        :param date_range: The date_range of this UpdateWorkPlanRotationAgentRequest.
        :type: DateRangeWithOptionalEnd
        """
        
        self._date_range = date_range

    @property
    def position(self):
        """
        Gets the position of this UpdateWorkPlanRotationAgentRequest.
        Start position of the work plan in the pattern for this agent in the work plan rotation. Position value starts from 0

        :return: The position of this UpdateWorkPlanRotationAgentRequest.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this UpdateWorkPlanRotationAgentRequest.
        Start position of the work plan in the pattern for this agent in the work plan rotation. Position value starts from 0

        :param position: The position of this UpdateWorkPlanRotationAgentRequest.
        :type: int
        """
        
        self._position = position

    @property
    def delete(self):
        """
        Gets the delete of this UpdateWorkPlanRotationAgentRequest.
        If marked true for this agent when updating, then this agent will be removed from this work plan rotation

        :return: The delete of this UpdateWorkPlanRotationAgentRequest.
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """
        Sets the delete of this UpdateWorkPlanRotationAgentRequest.
        If marked true for this agent when updating, then this agent will be removed from this work plan rotation

        :param delete: The delete of this UpdateWorkPlanRotationAgentRequest.
        :type: bool
        """
        
        self._delete = delete

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class GoogleDialogflowCustomSettings(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        GoogleDialogflowCustomSettings - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'environment': 'str',
            'event_name': 'str',
            'webhook_query_parameters': 'dict(str, str)',
            'event_input_parameters': 'dict(str, str)'
        }

        self.attribute_map = {
            'environment': 'environment',
            'event_name': 'eventName',
            'webhook_query_parameters': 'webhookQueryParameters',
            'event_input_parameters': 'eventInputParameters'
        }

        self._environment = None
        self._event_name = None
        self._webhook_query_parameters = None
        self._event_input_parameters = None

    @property
    def environment(self):
        """
        Gets the environment of this GoogleDialogflowCustomSettings.
        If set this environment will be used to initiate the dialogflow bot, otherwise the default configuration will be used.  See https://cloud.google.com/dialogflow/docs/agents-versions

        :return: The environment of this GoogleDialogflowCustomSettings.
        :rtype: str
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """
        Sets the environment of this GoogleDialogflowCustomSettings.
        If set this environment will be used to initiate the dialogflow bot, otherwise the default configuration will be used.  See https://cloud.google.com/dialogflow/docs/agents-versions

        :param environment: The environment of this GoogleDialogflowCustomSettings.
        :type: str
        """
        
        self._environment = environment

    @property
    def event_name(self):
        """
        Gets the event_name of this GoogleDialogflowCustomSettings.
        If set this eventName will be used to initiate the dialogflow bot rather than language processing on the input text.  See https://cloud.google.com/dialogflow/es/docs/events-overview

        :return: The event_name of this GoogleDialogflowCustomSettings.
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """
        Sets the event_name of this GoogleDialogflowCustomSettings.
        If set this eventName will be used to initiate the dialogflow bot rather than language processing on the input text.  See https://cloud.google.com/dialogflow/es/docs/events-overview

        :param event_name: The event_name of this GoogleDialogflowCustomSettings.
        :type: str
        """
        
        self._event_name = event_name

    @property
    def webhook_query_parameters(self):
        """
        Gets the webhook_query_parameters of this GoogleDialogflowCustomSettings.
        Parameters passed to the fulfillment webhook of the bot (if any).

        :return: The webhook_query_parameters of this GoogleDialogflowCustomSettings.
        :rtype: dict(str, str)
        """
        return self._webhook_query_parameters

    @webhook_query_parameters.setter
    def webhook_query_parameters(self, webhook_query_parameters):
        """
        Sets the webhook_query_parameters of this GoogleDialogflowCustomSettings.
        Parameters passed to the fulfillment webhook of the bot (if any).

        :param webhook_query_parameters: The webhook_query_parameters of this GoogleDialogflowCustomSettings.
        :type: dict(str, str)
        """
        
        self._webhook_query_parameters = webhook_query_parameters

    @property
    def event_input_parameters(self):
        """
        Gets the event_input_parameters of this GoogleDialogflowCustomSettings.
        Parameters passed to the event input of the bot.

        :return: The event_input_parameters of this GoogleDialogflowCustomSettings.
        :rtype: dict(str, str)
        """
        return self._event_input_parameters

    @event_input_parameters.setter
    def event_input_parameters(self, event_input_parameters):
        """
        Sets the event_input_parameters of this GoogleDialogflowCustomSettings.
        Parameters passed to the event input of the bot.

        :param event_input_parameters: The event_input_parameters of this GoogleDialogflowCustomSettings.
        :type: dict(str, str)
        """
        
        self._event_input_parameters = event_input_parameters

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationEventTopicEmail(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationEventTopicEmail - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'held': 'bool',
            'auto_generated': 'bool',
            'subject': 'str',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'messages_sent': 'int',
            'error_info': 'QueueConversationEventTopicErrorDetails',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'message_id': 'str',
            'direction': 'str',
            'draft_attachments': 'list[QueueConversationEventTopicAttachment]',
            'spam': 'bool',
            'wrapup': 'QueueConversationEventTopicWrapup',
            'after_call_work': 'QueueConversationEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'held': 'held',
            'auto_generated': 'autoGenerated',
            'subject': 'subject',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'messages_sent': 'messagesSent',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'message_id': 'messageId',
            'direction': 'direction',
            'draft_attachments': 'draftAttachments',
            'spam': 'spam',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._state = None
        self._held = None
        self._auto_generated = None
        self._subject = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._messages_sent = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._message_id = None
        self._direction = None
        self._draft_attachments = None
        self._spam = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationEventTopicEmail.


        :return: The id of this QueueConversationEventTopicEmail.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationEventTopicEmail.


        :param id: The id of this QueueConversationEventTopicEmail.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this QueueConversationEventTopicEmail.


        :return: The state of this QueueConversationEventTopicEmail.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationEventTopicEmail.


        :param state: The state of this QueueConversationEventTopicEmail.
        :type: str
        """
        allowed_values = ["ALERTING", "CONNECTED", "DISCONNECTED", "NONE", "TRANSMITTING"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def held(self):
        """
        Gets the held of this QueueConversationEventTopicEmail.


        :return: The held of this QueueConversationEventTopicEmail.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationEventTopicEmail.


        :param held: The held of this QueueConversationEventTopicEmail.
        :type: bool
        """
        
        self._held = held

    @property
    def auto_generated(self):
        """
        Gets the auto_generated of this QueueConversationEventTopicEmail.


        :return: The auto_generated of this QueueConversationEventTopicEmail.
        :rtype: bool
        """
        return self._auto_generated

    @auto_generated.setter
    def auto_generated(self, auto_generated):
        """
        Sets the auto_generated of this QueueConversationEventTopicEmail.


        :param auto_generated: The auto_generated of this QueueConversationEventTopicEmail.
        :type: bool
        """
        
        self._auto_generated = auto_generated

    @property
    def subject(self):
        """
        Gets the subject of this QueueConversationEventTopicEmail.


        :return: The subject of this QueueConversationEventTopicEmail.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this QueueConversationEventTopicEmail.


        :param subject: The subject of this QueueConversationEventTopicEmail.
        :type: str
        """
        
        self._subject = subject

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationEventTopicEmail.


        :return: The provider of this QueueConversationEventTopicEmail.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationEventTopicEmail.


        :param provider: The provider of this QueueConversationEventTopicEmail.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationEventTopicEmail.


        :return: The script_id of this QueueConversationEventTopicEmail.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationEventTopicEmail.


        :param script_id: The script_id of this QueueConversationEventTopicEmail.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationEventTopicEmail.


        :return: The peer_id of this QueueConversationEventTopicEmail.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationEventTopicEmail.


        :param peer_id: The peer_id of this QueueConversationEventTopicEmail.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def messages_sent(self):
        """
        Gets the messages_sent of this QueueConversationEventTopicEmail.


        :return: The messages_sent of this QueueConversationEventTopicEmail.
        :rtype: int
        """
        return self._messages_sent

    @messages_sent.setter
    def messages_sent(self, messages_sent):
        """
        Sets the messages_sent of this QueueConversationEventTopicEmail.


        :param messages_sent: The messages_sent of this QueueConversationEventTopicEmail.
        :type: int
        """
        
        self._messages_sent = messages_sent

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationEventTopicEmail.


        :return: The error_info of this QueueConversationEventTopicEmail.
        :rtype: QueueConversationEventTopicErrorDetails
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationEventTopicEmail.


        :param error_info: The error_info of this QueueConversationEventTopicEmail.
        :type: QueueConversationEventTopicErrorDetails
        """
        
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationEventTopicEmail.


        :return: The disconnect_type of this QueueConversationEventTopicEmail.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationEventTopicEmail.


        :param disconnect_type: The disconnect_type of this QueueConversationEventTopicEmail.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationEventTopicEmail.


        :return: The start_hold_time of this QueueConversationEventTopicEmail.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationEventTopicEmail.


        :param start_hold_time: The start_hold_time of this QueueConversationEventTopicEmail.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationEventTopicEmail.


        :return: The connected_time of this QueueConversationEventTopicEmail.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationEventTopicEmail.


        :param connected_time: The connected_time of this QueueConversationEventTopicEmail.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationEventTopicEmail.


        :return: The disconnected_time of this QueueConversationEventTopicEmail.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationEventTopicEmail.


        :param disconnected_time: The disconnected_time of this QueueConversationEventTopicEmail.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def message_id(self):
        """
        Gets the message_id of this QueueConversationEventTopicEmail.


        :return: The message_id of this QueueConversationEventTopicEmail.
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """
        Sets the message_id of this QueueConversationEventTopicEmail.


        :param message_id: The message_id of this QueueConversationEventTopicEmail.
        :type: str
        """
        
        self._message_id = message_id

    @property
    def direction(self):
        """
        Gets the direction of this QueueConversationEventTopicEmail.


        :return: The direction of this QueueConversationEventTopicEmail.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this QueueConversationEventTopicEmail.


        :param direction: The direction of this QueueConversationEventTopicEmail.
        :type: str
        """
        allowed_values = ["OUTBOUND", "INBOUND"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def draft_attachments(self):
        """
        Gets the draft_attachments of this QueueConversationEventTopicEmail.


        :return: The draft_attachments of this QueueConversationEventTopicEmail.
        :rtype: list[QueueConversationEventTopicAttachment]
        """
        return self._draft_attachments

    @draft_attachments.setter
    def draft_attachments(self, draft_attachments):
        """
        Sets the draft_attachments of this QueueConversationEventTopicEmail.


        :param draft_attachments: The draft_attachments of this QueueConversationEventTopicEmail.
        :type: list[QueueConversationEventTopicAttachment]
        """
        
        self._draft_attachments = draft_attachments

    @property
    def spam(self):
        """
        Gets the spam of this QueueConversationEventTopicEmail.


        :return: The spam of this QueueConversationEventTopicEmail.
        :rtype: bool
        """
        return self._spam

    @spam.setter
    def spam(self, spam):
        """
        Sets the spam of this QueueConversationEventTopicEmail.


        :param spam: The spam of this QueueConversationEventTopicEmail.
        :type: bool
        """
        
        self._spam = spam

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationEventTopicEmail.


        :return: The wrapup of this QueueConversationEventTopicEmail.
        :rtype: QueueConversationEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationEventTopicEmail.


        :param wrapup: The wrapup of this QueueConversationEventTopicEmail.
        :type: QueueConversationEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationEventTopicEmail.


        :return: The after_call_work of this QueueConversationEventTopicEmail.
        :rtype: QueueConversationEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationEventTopicEmail.


        :param after_call_work: The after_call_work of this QueueConversationEventTopicEmail.
        :type: QueueConversationEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationEventTopicEmail.


        :return: The after_call_work_required of this QueueConversationEventTopicEmail.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationEventTopicEmail.


        :param after_call_work_required: The after_call_work_required of this QueueConversationEventTopicEmail.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationEventTopicEmail.


        :return: The additional_properties of this QueueConversationEventTopicEmail.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationEventTopicEmail.


        :param additional_properties: The additional_properties of this QueueConversationEventTopicEmail.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SchemaQuantityLimits(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SchemaQuantityLimits - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'min_field_name_characters': 'int',
            'max_field_name_characters': 'int',
            'min_field_description_characters': 'int',
            'max_field_description_characters': 'int',
            'min_schema_name_characters': 'int',
            'max_schema_name_characters': 'int',
            'min_schema_description_characters': 'int',
            'max_schema_description_characters': 'int',
            'max_number_of_schemas_per_org': 'int',
            'max_number_of_fields_per_schema': 'int',
            'max_number_of_fields_per_org': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'min_field_name_characters': 'minFieldNameCharacters',
            'max_field_name_characters': 'maxFieldNameCharacters',
            'min_field_description_characters': 'minFieldDescriptionCharacters',
            'max_field_description_characters': 'maxFieldDescriptionCharacters',
            'min_schema_name_characters': 'minSchemaNameCharacters',
            'max_schema_name_characters': 'maxSchemaNameCharacters',
            'min_schema_description_characters': 'minSchemaDescriptionCharacters',
            'max_schema_description_characters': 'maxSchemaDescriptionCharacters',
            'max_number_of_schemas_per_org': 'maxNumberOfSchemasPerOrg',
            'max_number_of_fields_per_schema': 'maxNumberOfFieldsPerSchema',
            'max_number_of_fields_per_org': 'maxNumberOfFieldsPerOrg',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._min_field_name_characters = None
        self._max_field_name_characters = None
        self._min_field_description_characters = None
        self._max_field_description_characters = None
        self._min_schema_name_characters = None
        self._max_schema_name_characters = None
        self._min_schema_description_characters = None
        self._max_schema_description_characters = None
        self._max_number_of_schemas_per_org = None
        self._max_number_of_fields_per_schema = None
        self._max_number_of_fields_per_org = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this SchemaQuantityLimits.
        The globally unique identifier for the object.

        :return: The id of this SchemaQuantityLimits.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SchemaQuantityLimits.
        The globally unique identifier for the object.

        :param id: The id of this SchemaQuantityLimits.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this SchemaQuantityLimits.


        :return: The name of this SchemaQuantityLimits.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SchemaQuantityLimits.


        :param name: The name of this SchemaQuantityLimits.
        :type: str
        """
        
        self._name = name

    @property
    def min_field_name_characters(self):
        """
        Gets the min_field_name_characters of this SchemaQuantityLimits.
        The minimum number of schema field name characters allowed.

        :return: The min_field_name_characters of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._min_field_name_characters

    @min_field_name_characters.setter
    def min_field_name_characters(self, min_field_name_characters):
        """
        Sets the min_field_name_characters of this SchemaQuantityLimits.
        The minimum number of schema field name characters allowed.

        :param min_field_name_characters: The min_field_name_characters of this SchemaQuantityLimits.
        :type: int
        """
        
        self._min_field_name_characters = min_field_name_characters

    @property
    def max_field_name_characters(self):
        """
        Gets the max_field_name_characters of this SchemaQuantityLimits.
        The maximum number of schema field name characters allowed.

        :return: The max_field_name_characters of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._max_field_name_characters

    @max_field_name_characters.setter
    def max_field_name_characters(self, max_field_name_characters):
        """
        Sets the max_field_name_characters of this SchemaQuantityLimits.
        The maximum number of schema field name characters allowed.

        :param max_field_name_characters: The max_field_name_characters of this SchemaQuantityLimits.
        :type: int
        """
        
        self._max_field_name_characters = max_field_name_characters

    @property
    def min_field_description_characters(self):
        """
        Gets the min_field_description_characters of this SchemaQuantityLimits.
        The minimum number of schema field description characters allowed.

        :return: The min_field_description_characters of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._min_field_description_characters

    @min_field_description_characters.setter
    def min_field_description_characters(self, min_field_description_characters):
        """
        Sets the min_field_description_characters of this SchemaQuantityLimits.
        The minimum number of schema field description characters allowed.

        :param min_field_description_characters: The min_field_description_characters of this SchemaQuantityLimits.
        :type: int
        """
        
        self._min_field_description_characters = min_field_description_characters

    @property
    def max_field_description_characters(self):
        """
        Gets the max_field_description_characters of this SchemaQuantityLimits.
        The maximum number of schema field description characters allowed.

        :return: The max_field_description_characters of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._max_field_description_characters

    @max_field_description_characters.setter
    def max_field_description_characters(self, max_field_description_characters):
        """
        Sets the max_field_description_characters of this SchemaQuantityLimits.
        The maximum number of schema field description characters allowed.

        :param max_field_description_characters: The max_field_description_characters of this SchemaQuantityLimits.
        :type: int
        """
        
        self._max_field_description_characters = max_field_description_characters

    @property
    def min_schema_name_characters(self):
        """
        Gets the min_schema_name_characters of this SchemaQuantityLimits.
        The minimum number of schema name characters allowed.

        :return: The min_schema_name_characters of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._min_schema_name_characters

    @min_schema_name_characters.setter
    def min_schema_name_characters(self, min_schema_name_characters):
        """
        Sets the min_schema_name_characters of this SchemaQuantityLimits.
        The minimum number of schema name characters allowed.

        :param min_schema_name_characters: The min_schema_name_characters of this SchemaQuantityLimits.
        :type: int
        """
        
        self._min_schema_name_characters = min_schema_name_characters

    @property
    def max_schema_name_characters(self):
        """
        Gets the max_schema_name_characters of this SchemaQuantityLimits.
        The maximum number of schema name characters allowed.

        :return: The max_schema_name_characters of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._max_schema_name_characters

    @max_schema_name_characters.setter
    def max_schema_name_characters(self, max_schema_name_characters):
        """
        Sets the max_schema_name_characters of this SchemaQuantityLimits.
        The maximum number of schema name characters allowed.

        :param max_schema_name_characters: The max_schema_name_characters of this SchemaQuantityLimits.
        :type: int
        """
        
        self._max_schema_name_characters = max_schema_name_characters

    @property
    def min_schema_description_characters(self):
        """
        Gets the min_schema_description_characters of this SchemaQuantityLimits.
        The minimum number of schema description characters allowed.

        :return: The min_schema_description_characters of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._min_schema_description_characters

    @min_schema_description_characters.setter
    def min_schema_description_characters(self, min_schema_description_characters):
        """
        Sets the min_schema_description_characters of this SchemaQuantityLimits.
        The minimum number of schema description characters allowed.

        :param min_schema_description_characters: The min_schema_description_characters of this SchemaQuantityLimits.
        :type: int
        """
        
        self._min_schema_description_characters = min_schema_description_characters

    @property
    def max_schema_description_characters(self):
        """
        Gets the max_schema_description_characters of this SchemaQuantityLimits.
        The maximum number of schema description characters allowed.

        :return: The max_schema_description_characters of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._max_schema_description_characters

    @max_schema_description_characters.setter
    def max_schema_description_characters(self, max_schema_description_characters):
        """
        Sets the max_schema_description_characters of this SchemaQuantityLimits.
        The maximum number of schema description characters allowed.

        :param max_schema_description_characters: The max_schema_description_characters of this SchemaQuantityLimits.
        :type: int
        """
        
        self._max_schema_description_characters = max_schema_description_characters

    @property
    def max_number_of_schemas_per_org(self):
        """
        Gets the max_number_of_schemas_per_org of this SchemaQuantityLimits.
        The maximum number of schema allowed per org.

        :return: The max_number_of_schemas_per_org of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._max_number_of_schemas_per_org

    @max_number_of_schemas_per_org.setter
    def max_number_of_schemas_per_org(self, max_number_of_schemas_per_org):
        """
        Sets the max_number_of_schemas_per_org of this SchemaQuantityLimits.
        The maximum number of schema allowed per org.

        :param max_number_of_schemas_per_org: The max_number_of_schemas_per_org of this SchemaQuantityLimits.
        :type: int
        """
        
        self._max_number_of_schemas_per_org = max_number_of_schemas_per_org

    @property
    def max_number_of_fields_per_schema(self):
        """
        Gets the max_number_of_fields_per_schema of this SchemaQuantityLimits.
        The maximum number of schema fields allowed per schema.

        :return: The max_number_of_fields_per_schema of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._max_number_of_fields_per_schema

    @max_number_of_fields_per_schema.setter
    def max_number_of_fields_per_schema(self, max_number_of_fields_per_schema):
        """
        Sets the max_number_of_fields_per_schema of this SchemaQuantityLimits.
        The maximum number of schema fields allowed per schema.

        :param max_number_of_fields_per_schema: The max_number_of_fields_per_schema of this SchemaQuantityLimits.
        :type: int
        """
        
        self._max_number_of_fields_per_schema = max_number_of_fields_per_schema

    @property
    def max_number_of_fields_per_org(self):
        """
        Gets the max_number_of_fields_per_org of this SchemaQuantityLimits.
        The maximum number of schema fields allowed per organization across all of their schemas.

        :return: The max_number_of_fields_per_org of this SchemaQuantityLimits.
        :rtype: int
        """
        return self._max_number_of_fields_per_org

    @max_number_of_fields_per_org.setter
    def max_number_of_fields_per_org(self, max_number_of_fields_per_org):
        """
        Sets the max_number_of_fields_per_org of this SchemaQuantityLimits.
        The maximum number of schema fields allowed per organization across all of their schemas.

        :param max_number_of_fields_per_org: The max_number_of_fields_per_org of this SchemaQuantityLimits.
        :type: int
        """
        
        self._max_number_of_fields_per_org = max_number_of_fields_per_org

    @property
    def self_uri(self):
        """
        Gets the self_uri of this SchemaQuantityLimits.
        The URI for this object

        :return: The self_uri of this SchemaQuantityLimits.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this SchemaQuantityLimits.
        The URI for this object

        :param self_uri: The self_uri of this SchemaQuantityLimits.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ActionInput(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ActionInput - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'input_schema': 'JsonSchemaDocument',
            'input_schema_flattened': 'JsonSchemaDocument',
            'input_schema_uri': 'str'
        }

        self.attribute_map = {
            'input_schema': 'inputSchema',
            'input_schema_flattened': 'inputSchemaFlattened',
            'input_schema_uri': 'inputSchemaUri'
        }

        self._input_schema = None
        self._input_schema_flattened = None
        self._input_schema_uri = None

    @property
    def input_schema(self):
        """
        Gets the input_schema of this ActionInput.
        JSON Schema that defines the body of the request that the client (edge/architect/postman) is sending to the service, on the /execute path. If the 'flatten' query parameter is omitted or false, this field will be returned. Either inputSchema or inputSchemaFlattened will be returned, not both.

        :return: The input_schema of this ActionInput.
        :rtype: JsonSchemaDocument
        """
        return self._input_schema

    @input_schema.setter
    def input_schema(self, input_schema):
        """
        Sets the input_schema of this ActionInput.
        JSON Schema that defines the body of the request that the client (edge/architect/postman) is sending to the service, on the /execute path. If the 'flatten' query parameter is omitted or false, this field will be returned. Either inputSchema or inputSchemaFlattened will be returned, not both.

        :param input_schema: The input_schema of this ActionInput.
        :type: JsonSchemaDocument
        """
        
        self._input_schema = input_schema

    @property
    def input_schema_flattened(self):
        """
        Gets the input_schema_flattened of this ActionInput.
        JSON Schema that defines the body of the request that the client (edge/architect/postman) is sending to the service, on the /execute path. The schema is transformed based on Architect's flattened format. If the 'flatten' query parameter is supplied as true, this field will be returned. Either inputSchema or inputSchemaFlattened will be returned, not both.

        :return: The input_schema_flattened of this ActionInput.
        :rtype: JsonSchemaDocument
        """
        return self._input_schema_flattened

    @input_schema_flattened.setter
    def input_schema_flattened(self, input_schema_flattened):
        """
        Sets the input_schema_flattened of this ActionInput.
        JSON Schema that defines the body of the request that the client (edge/architect/postman) is sending to the service, on the /execute path. The schema is transformed based on Architect's flattened format. If the 'flatten' query parameter is supplied as true, this field will be returned. Either inputSchema or inputSchemaFlattened will be returned, not both.

        :param input_schema_flattened: The input_schema_flattened of this ActionInput.
        :type: JsonSchemaDocument
        """
        
        self._input_schema_flattened = input_schema_flattened

    @property
    def input_schema_uri(self):
        """
        Gets the input_schema_uri of this ActionInput.
        The URI of the input schema

        :return: The input_schema_uri of this ActionInput.
        :rtype: str
        """
        return self._input_schema_uri

    @input_schema_uri.setter
    def input_schema_uri(self, input_schema_uri):
        """
        Sets the input_schema_uri of this ActionInput.
        The URI of the input schema

        :param input_schema_uri: The input_schema_uri of this ActionInput.
        :type: str
        """
        
        self._input_schema_uri = input_schema_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MessagingCampaign(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MessagingCampaign - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'division': 'DomainEntityRef',
            'campaign_status': 'str',
            'callable_time_set': 'DomainEntityRef',
            'contact_list': 'DomainEntityRef',
            'dnc_lists': 'list[DomainEntityRef]',
            'always_running': 'bool',
            'contact_sorts': 'list[ContactSort]',
            'messages_per_minute': 'int',
            'errors': 'list[RestErrorDetail]',
            'sms_config': 'SmsConfig',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'division': 'division',
            'campaign_status': 'campaignStatus',
            'callable_time_set': 'callableTimeSet',
            'contact_list': 'contactList',
            'dnc_lists': 'dncLists',
            'always_running': 'alwaysRunning',
            'contact_sorts': 'contactSorts',
            'messages_per_minute': 'messagesPerMinute',
            'errors': 'errors',
            'sms_config': 'smsConfig',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._division = None
        self._campaign_status = None
        self._callable_time_set = None
        self._contact_list = None
        self._dnc_lists = None
        self._always_running = None
        self._contact_sorts = None
        self._messages_per_minute = None
        self._errors = None
        self._sms_config = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this MessagingCampaign.
        The globally unique identifier for the object.

        :return: The id of this MessagingCampaign.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MessagingCampaign.
        The globally unique identifier for the object.

        :param id: The id of this MessagingCampaign.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this MessagingCampaign.


        :return: The name of this MessagingCampaign.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MessagingCampaign.


        :param name: The name of this MessagingCampaign.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this MessagingCampaign.
        Creation time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this MessagingCampaign.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this MessagingCampaign.
        Creation time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this MessagingCampaign.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this MessagingCampaign.
        Last modified time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this MessagingCampaign.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this MessagingCampaign.
        Last modified time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this MessagingCampaign.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this MessagingCampaign.
        Required for updates, must match the version number of the most recent update

        :return: The version of this MessagingCampaign.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this MessagingCampaign.
        Required for updates, must match the version number of the most recent update

        :param version: The version of this MessagingCampaign.
        :type: int
        """
        
        self._version = version

    @property
    def division(self):
        """
        Gets the division of this MessagingCampaign.
        The division this entity belongs to.

        :return: The division of this MessagingCampaign.
        :rtype: DomainEntityRef
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this MessagingCampaign.
        The division this entity belongs to.

        :param division: The division of this MessagingCampaign.
        :type: DomainEntityRef
        """
        
        self._division = division

    @property
    def campaign_status(self):
        """
        Gets the campaign_status of this MessagingCampaign.
        The current status of the messaging campaign. A messaging campaign may be turned 'on' or 'off'.

        :return: The campaign_status of this MessagingCampaign.
        :rtype: str
        """
        return self._campaign_status

    @campaign_status.setter
    def campaign_status(self, campaign_status):
        """
        Sets the campaign_status of this MessagingCampaign.
        The current status of the messaging campaign. A messaging campaign may be turned 'on' or 'off'.

        :param campaign_status: The campaign_status of this MessagingCampaign.
        :type: str
        """
        allowed_values = ["on", "stopping", "off", "complete", "invalid"]
        if campaign_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for campaign_status -> " + campaign_status)
            self._campaign_status = "outdated_sdk_version"
        else:
            self._campaign_status = campaign_status

    @property
    def callable_time_set(self):
        """
        Gets the callable_time_set of this MessagingCampaign.
        The callable time set for this messaging campaign.

        :return: The callable_time_set of this MessagingCampaign.
        :rtype: DomainEntityRef
        """
        return self._callable_time_set

    @callable_time_set.setter
    def callable_time_set(self, callable_time_set):
        """
        Sets the callable_time_set of this MessagingCampaign.
        The callable time set for this messaging campaign.

        :param callable_time_set: The callable_time_set of this MessagingCampaign.
        :type: DomainEntityRef
        """
        
        self._callable_time_set = callable_time_set

    @property
    def contact_list(self):
        """
        Gets the contact_list of this MessagingCampaign.
        The contact list that this messaging campaign will send messages for.

        :return: The contact_list of this MessagingCampaign.
        :rtype: DomainEntityRef
        """
        return self._contact_list

    @contact_list.setter
    def contact_list(self, contact_list):
        """
        Sets the contact_list of this MessagingCampaign.
        The contact list that this messaging campaign will send messages for.

        :param contact_list: The contact_list of this MessagingCampaign.
        :type: DomainEntityRef
        """
        
        self._contact_list = contact_list

    @property
    def dnc_lists(self):
        """
        Gets the dnc_lists of this MessagingCampaign.
        The dnc lists to check before sending a message for this messaging campaign.

        :return: The dnc_lists of this MessagingCampaign.
        :rtype: list[DomainEntityRef]
        """
        return self._dnc_lists

    @dnc_lists.setter
    def dnc_lists(self, dnc_lists):
        """
        Sets the dnc_lists of this MessagingCampaign.
        The dnc lists to check before sending a message for this messaging campaign.

        :param dnc_lists: The dnc_lists of this MessagingCampaign.
        :type: list[DomainEntityRef]
        """
        
        self._dnc_lists = dnc_lists

    @property
    def always_running(self):
        """
        Gets the always_running of this MessagingCampaign.
        Whether this messaging campaign is always running

        :return: The always_running of this MessagingCampaign.
        :rtype: bool
        """
        return self._always_running

    @always_running.setter
    def always_running(self, always_running):
        """
        Sets the always_running of this MessagingCampaign.
        Whether this messaging campaign is always running

        :param always_running: The always_running of this MessagingCampaign.
        :type: bool
        """
        
        self._always_running = always_running

    @property
    def contact_sorts(self):
        """
        Gets the contact_sorts of this MessagingCampaign.
        The order in which to sort contacts for dialing, based on up to four columns.

        :return: The contact_sorts of this MessagingCampaign.
        :rtype: list[ContactSort]
        """
        return self._contact_sorts

    @contact_sorts.setter
    def contact_sorts(self, contact_sorts):
        """
        Sets the contact_sorts of this MessagingCampaign.
        The order in which to sort contacts for dialing, based on up to four columns.

        :param contact_sorts: The contact_sorts of this MessagingCampaign.
        :type: list[ContactSort]
        """
        
        self._contact_sorts = contact_sorts

    @property
    def messages_per_minute(self):
        """
        Gets the messages_per_minute of this MessagingCampaign.
        How many messages this messaging campaign will send per minute.

        :return: The messages_per_minute of this MessagingCampaign.
        :rtype: int
        """
        return self._messages_per_minute

    @messages_per_minute.setter
    def messages_per_minute(self, messages_per_minute):
        """
        Sets the messages_per_minute of this MessagingCampaign.
        How many messages this messaging campaign will send per minute.

        :param messages_per_minute: The messages_per_minute of this MessagingCampaign.
        :type: int
        """
        
        self._messages_per_minute = messages_per_minute

    @property
    def errors(self):
        """
        Gets the errors of this MessagingCampaign.
        A list of current error conditions associated with this messaging campaign.

        :return: The errors of this MessagingCampaign.
        :rtype: list[RestErrorDetail]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this MessagingCampaign.
        A list of current error conditions associated with this messaging campaign.

        :param errors: The errors of this MessagingCampaign.
        :type: list[RestErrorDetail]
        """
        
        self._errors = errors

    @property
    def sms_config(self):
        """
        Gets the sms_config of this MessagingCampaign.
        Configuration for this messaging campaign to send SMS messages.

        :return: The sms_config of this MessagingCampaign.
        :rtype: SmsConfig
        """
        return self._sms_config

    @sms_config.setter
    def sms_config(self, sms_config):
        """
        Sets the sms_config of this MessagingCampaign.
        Configuration for this messaging campaign to send SMS messages.

        :param sms_config: The sms_config of this MessagingCampaign.
        :type: SmsConfig
        """
        
        self._sms_config = sms_config

    @property
    def self_uri(self):
        """
        Gets the self_uri of this MessagingCampaign.
        The URI for this object

        :return: The self_uri of this MessagingCampaign.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this MessagingCampaign.
        The URI for this object

        :param self_uri: The self_uri of this MessagingCampaign.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WebChatMemberInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WebChatMemberInfo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'first_name': 'str',
            'last_name': 'str',
            'email': 'str',
            'phone_number': 'str',
            'avatar_image_url': 'str',
            'role': 'str',
            'join_date': 'datetime',
            'leave_date': 'datetime',
            'authenticated_guest': 'bool',
            'custom_fields': 'dict(str, str)',
            'state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'first_name': 'firstName',
            'last_name': 'lastName',
            'email': 'email',
            'phone_number': 'phoneNumber',
            'avatar_image_url': 'avatarImageUrl',
            'role': 'role',
            'join_date': 'joinDate',
            'leave_date': 'leaveDate',
            'authenticated_guest': 'authenticatedGuest',
            'custom_fields': 'customFields',
            'state': 'state'
        }

        self._id = None
        self._display_name = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._phone_number = None
        self._avatar_image_url = None
        self._role = None
        self._join_date = None
        self._leave_date = None
        self._authenticated_guest = None
        self._custom_fields = None
        self._state = None

    @property
    def id(self):
        """
        Gets the id of this WebChatMemberInfo.
        The communicationId of this member.

        :return: The id of this WebChatMemberInfo.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WebChatMemberInfo.
        The communicationId of this member.

        :param id: The id of this WebChatMemberInfo.
        :type: str
        """
        
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this WebChatMemberInfo.
        The display name of the member.

        :return: The display_name of this WebChatMemberInfo.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this WebChatMemberInfo.
        The display name of the member.

        :param display_name: The display_name of this WebChatMemberInfo.
        :type: str
        """
        
        self._display_name = display_name

    @property
    def first_name(self):
        """
        Gets the first_name of this WebChatMemberInfo.
        The first name of the member.

        :return: The first_name of this WebChatMemberInfo.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this WebChatMemberInfo.
        The first name of the member.

        :param first_name: The first_name of this WebChatMemberInfo.
        :type: str
        """
        
        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this WebChatMemberInfo.
        The last name of the member.

        :return: The last_name of this WebChatMemberInfo.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this WebChatMemberInfo.
        The last name of the member.

        :param last_name: The last_name of this WebChatMemberInfo.
        :type: str
        """
        
        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this WebChatMemberInfo.
        The email address of the member.

        :return: The email of this WebChatMemberInfo.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this WebChatMemberInfo.
        The email address of the member.

        :param email: The email of this WebChatMemberInfo.
        :type: str
        """
        
        self._email = email

    @property
    def phone_number(self):
        """
        Gets the phone_number of this WebChatMemberInfo.
        The phone number of the member.

        :return: The phone_number of this WebChatMemberInfo.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this WebChatMemberInfo.
        The phone number of the member.

        :param phone_number: The phone_number of this WebChatMemberInfo.
        :type: str
        """
        
        self._phone_number = phone_number

    @property
    def avatar_image_url(self):
        """
        Gets the avatar_image_url of this WebChatMemberInfo.
        The url to the avatar image of the member.

        :return: The avatar_image_url of this WebChatMemberInfo.
        :rtype: str
        """
        return self._avatar_image_url

    @avatar_image_url.setter
    def avatar_image_url(self, avatar_image_url):
        """
        Sets the avatar_image_url of this WebChatMemberInfo.
        The url to the avatar image of the member.

        :param avatar_image_url: The avatar_image_url of this WebChatMemberInfo.
        :type: str
        """
        
        self._avatar_image_url = avatar_image_url

    @property
    def role(self):
        """
        Gets the role of this WebChatMemberInfo.
        The role of the member, one of [agent, customer, acd, workflow]

        :return: The role of this WebChatMemberInfo.
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """
        Sets the role of this WebChatMemberInfo.
        The role of the member, one of [agent, customer, acd, workflow]

        :param role: The role of this WebChatMemberInfo.
        :type: str
        """
        allowed_values = ["AGENT", "CUSTOMER", "WORKFLOW", "ACD"]
        if role.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for role -> " + role)
            self._role = "outdated_sdk_version"
        else:
            self._role = role

    @property
    def join_date(self):
        """
        Gets the join_date of this WebChatMemberInfo.
        The time the member joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The join_date of this WebChatMemberInfo.
        :rtype: datetime
        """
        return self._join_date

    @join_date.setter
    def join_date(self, join_date):
        """
        Sets the join_date of this WebChatMemberInfo.
        The time the member joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param join_date: The join_date of this WebChatMemberInfo.
        :type: datetime
        """
        
        self._join_date = join_date

    @property
    def leave_date(self):
        """
        Gets the leave_date of this WebChatMemberInfo.
        The time the member left the conversation, or null if the member is still active in the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The leave_date of this WebChatMemberInfo.
        :rtype: datetime
        """
        return self._leave_date

    @leave_date.setter
    def leave_date(self, leave_date):
        """
        Sets the leave_date of this WebChatMemberInfo.
        The time the member left the conversation, or null if the member is still active in the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param leave_date: The leave_date of this WebChatMemberInfo.
        :type: datetime
        """
        
        self._leave_date = leave_date

    @property
    def authenticated_guest(self):
        """
        Gets the authenticated_guest of this WebChatMemberInfo.
        If true, the guest member is an authenticated guest.

        :return: The authenticated_guest of this WebChatMemberInfo.
        :rtype: bool
        """
        return self._authenticated_guest

    @authenticated_guest.setter
    def authenticated_guest(self, authenticated_guest):
        """
        Sets the authenticated_guest of this WebChatMemberInfo.
        If true, the guest member is an authenticated guest.

        :param authenticated_guest: The authenticated_guest of this WebChatMemberInfo.
        :type: bool
        """
        
        self._authenticated_guest = authenticated_guest

    @property
    def custom_fields(self):
        """
        Gets the custom_fields of this WebChatMemberInfo.
        Any custom fields of information pertaining to this member.

        :return: The custom_fields of this WebChatMemberInfo.
        :rtype: dict(str, str)
        """
        return self._custom_fields

    @custom_fields.setter
    def custom_fields(self, custom_fields):
        """
        Sets the custom_fields of this WebChatMemberInfo.
        Any custom fields of information pertaining to this member.

        :param custom_fields: The custom_fields of this WebChatMemberInfo.
        :type: dict(str, str)
        """
        
        self._custom_fields = custom_fields

    @property
    def state(self):
        """
        Gets the state of this WebChatMemberInfo.
        The connection state of this member.

        :return: The state of this WebChatMemberInfo.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this WebChatMemberInfo.
        The connection state of this member.

        :param state: The state of this WebChatMemberInfo.
        :type: str
        """
        allowed_values = ["CONNECTED", "DISCONNECTED", "ALERTING"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ListedProgram(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ListedProgram - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'published': 'bool',
            'topics_count': 'int',
            'tags': 'list[str]',
            'modified_by': 'AddressableEntityRef',
            'date_modified': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'published': 'published',
            'topics_count': 'topicsCount',
            'tags': 'tags',
            'modified_by': 'modifiedBy',
            'date_modified': 'dateModified',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._published = None
        self._topics_count = None
        self._tags = None
        self._modified_by = None
        self._date_modified = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ListedProgram.
        The globally unique identifier for the object.

        :return: The id of this ListedProgram.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ListedProgram.
        The globally unique identifier for the object.

        :param id: The id of this ListedProgram.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ListedProgram.


        :return: The name of this ListedProgram.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ListedProgram.


        :param name: The name of this ListedProgram.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ListedProgram.


        :return: The description of this ListedProgram.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ListedProgram.


        :param description: The description of this ListedProgram.
        :type: str
        """
        
        self._description = description

    @property
    def published(self):
        """
        Gets the published of this ListedProgram.


        :return: The published of this ListedProgram.
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """
        Sets the published of this ListedProgram.


        :param published: The published of this ListedProgram.
        :type: bool
        """
        
        self._published = published

    @property
    def topics_count(self):
        """
        Gets the topics_count of this ListedProgram.


        :return: The topics_count of this ListedProgram.
        :rtype: int
        """
        return self._topics_count

    @topics_count.setter
    def topics_count(self, topics_count):
        """
        Sets the topics_count of this ListedProgram.


        :param topics_count: The topics_count of this ListedProgram.
        :type: int
        """
        
        self._topics_count = topics_count

    @property
    def tags(self):
        """
        Gets the tags of this ListedProgram.


        :return: The tags of this ListedProgram.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this ListedProgram.


        :param tags: The tags of this ListedProgram.
        :type: list[str]
        """
        
        self._tags = tags

    @property
    def modified_by(self):
        """
        Gets the modified_by of this ListedProgram.


        :return: The modified_by of this ListedProgram.
        :rtype: AddressableEntityRef
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this ListedProgram.


        :param modified_by: The modified_by of this ListedProgram.
        :type: AddressableEntityRef
        """
        
        self._modified_by = modified_by

    @property
    def date_modified(self):
        """
        Gets the date_modified of this ListedProgram.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this ListedProgram.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this ListedProgram.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this ListedProgram.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ListedProgram.
        The URI for this object

        :return: The self_uri of this ListedProgram.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ListedProgram.
        The URI for this object

        :param self_uri: The self_uri of this ListedProgram.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TrustUser(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TrustUser - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'division': 'Division',
            'chat': 'Chat',
            'department': 'str',
            'email': 'str',
            'primary_contact_info': 'list[Contact]',
            'addresses': 'list[Contact]',
            'state': 'str',
            'title': 'str',
            'username': 'str',
            'manager': 'User',
            'images': 'list[UserImage]',
            'version': 'int',
            'certifications': 'list[str]',
            'biography': 'Biography',
            'employer_info': 'EmployerInfo',
            'routing_status': 'RoutingStatus',
            'presence': 'UserPresence',
            'conversation_summary': 'UserConversationSummary',
            'out_of_office': 'OutOfOffice',
            'geolocation': 'Geolocation',
            'station': 'UserStations',
            'authorization': 'UserAuthorization',
            'profile_skills': 'list[str]',
            'locations': 'list[Location]',
            'groups': 'list[Group]',
            'team': 'Team',
            'skills': 'list[UserRoutingSkill]',
            'languages': 'list[UserRoutingLanguage]',
            'acd_auto_answer': 'bool',
            'language_preference': 'str',
            'last_token_issued': 'OAuthLastTokenIssued',
            'trust_user_details': 'TrustUserDetails'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'division': 'division',
            'chat': 'chat',
            'department': 'department',
            'email': 'email',
            'primary_contact_info': 'primaryContactInfo',
            'addresses': 'addresses',
            'state': 'state',
            'title': 'title',
            'username': 'username',
            'manager': 'manager',
            'images': 'images',
            'version': 'version',
            'certifications': 'certifications',
            'biography': 'biography',
            'employer_info': 'employerInfo',
            'routing_status': 'routingStatus',
            'presence': 'presence',
            'conversation_summary': 'conversationSummary',
            'out_of_office': 'outOfOffice',
            'geolocation': 'geolocation',
            'station': 'station',
            'authorization': 'authorization',
            'profile_skills': 'profileSkills',
            'locations': 'locations',
            'groups': 'groups',
            'team': 'team',
            'skills': 'skills',
            'languages': 'languages',
            'acd_auto_answer': 'acdAutoAnswer',
            'language_preference': 'languagePreference',
            'last_token_issued': 'lastTokenIssued',
            'trust_user_details': 'trustUserDetails'
        }

        self._id = None
        self._name = None
        self._division = None
        self._chat = None
        self._department = None
        self._email = None
        self._primary_contact_info = None
        self._addresses = None
        self._state = None
        self._title = None
        self._username = None
        self._manager = None
        self._images = None
        self._version = None
        self._certifications = None
        self._biography = None
        self._employer_info = None
        self._routing_status = None
        self._presence = None
        self._conversation_summary = None
        self._out_of_office = None
        self._geolocation = None
        self._station = None
        self._authorization = None
        self._profile_skills = None
        self._locations = None
        self._groups = None
        self._team = None
        self._skills = None
        self._languages = None
        self._acd_auto_answer = None
        self._language_preference = None
        self._last_token_issued = None
        self._trust_user_details = None

    @property
    def id(self):
        """
        Gets the id of this TrustUser.
        The globally unique identifier for the object.

        :return: The id of this TrustUser.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TrustUser.
        The globally unique identifier for the object.

        :param id: The id of this TrustUser.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this TrustUser.


        :return: The name of this TrustUser.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TrustUser.


        :param name: The name of this TrustUser.
        :type: str
        """
        
        self._name = name

    @property
    def division(self):
        """
        Gets the division of this TrustUser.
        The division to which this entity belongs.

        :return: The division of this TrustUser.
        :rtype: Division
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this TrustUser.
        The division to which this entity belongs.

        :param division: The division of this TrustUser.
        :type: Division
        """
        
        self._division = division

    @property
    def chat(self):
        """
        Gets the chat of this TrustUser.


        :return: The chat of this TrustUser.
        :rtype: Chat
        """
        return self._chat

    @chat.setter
    def chat(self, chat):
        """
        Sets the chat of this TrustUser.


        :param chat: The chat of this TrustUser.
        :type: Chat
        """
        
        self._chat = chat

    @property
    def department(self):
        """
        Gets the department of this TrustUser.


        :return: The department of this TrustUser.
        :rtype: str
        """
        return self._department

    @department.setter
    def department(self, department):
        """
        Sets the department of this TrustUser.


        :param department: The department of this TrustUser.
        :type: str
        """
        
        self._department = department

    @property
    def email(self):
        """
        Gets the email of this TrustUser.


        :return: The email of this TrustUser.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this TrustUser.


        :param email: The email of this TrustUser.
        :type: str
        """
        
        self._email = email

    @property
    def primary_contact_info(self):
        """
        Gets the primary_contact_info of this TrustUser.
        Auto populated from addresses.

        :return: The primary_contact_info of this TrustUser.
        :rtype: list[Contact]
        """
        return self._primary_contact_info

    @primary_contact_info.setter
    def primary_contact_info(self, primary_contact_info):
        """
        Sets the primary_contact_info of this TrustUser.
        Auto populated from addresses.

        :param primary_contact_info: The primary_contact_info of this TrustUser.
        :type: list[Contact]
        """
        
        self._primary_contact_info = primary_contact_info

    @property
    def addresses(self):
        """
        Gets the addresses of this TrustUser.
        Email addresses and phone numbers for this user

        :return: The addresses of this TrustUser.
        :rtype: list[Contact]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this TrustUser.
        Email addresses and phone numbers for this user

        :param addresses: The addresses of this TrustUser.
        :type: list[Contact]
        """
        
        self._addresses = addresses

    @property
    def state(self):
        """
        Gets the state of this TrustUser.
        The current state for this user.

        :return: The state of this TrustUser.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this TrustUser.
        The current state for this user.

        :param state: The state of this TrustUser.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def title(self):
        """
        Gets the title of this TrustUser.


        :return: The title of this TrustUser.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this TrustUser.


        :param title: The title of this TrustUser.
        :type: str
        """
        
        self._title = title

    @property
    def username(self):
        """
        Gets the username of this TrustUser.


        :return: The username of this TrustUser.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this TrustUser.


        :param username: The username of this TrustUser.
        :type: str
        """
        
        self._username = username

    @property
    def manager(self):
        """
        Gets the manager of this TrustUser.


        :return: The manager of this TrustUser.
        :rtype: User
        """
        return self._manager

    @manager.setter
    def manager(self, manager):
        """
        Sets the manager of this TrustUser.


        :param manager: The manager of this TrustUser.
        :type: User
        """
        
        self._manager = manager

    @property
    def images(self):
        """
        Gets the images of this TrustUser.


        :return: The images of this TrustUser.
        :rtype: list[UserImage]
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this TrustUser.


        :param images: The images of this TrustUser.
        :type: list[UserImage]
        """
        
        self._images = images

    @property
    def version(self):
        """
        Gets the version of this TrustUser.
        Required when updating a user, this value should be the current version of the user.  The current version can be obtained with a GET on the user before doing a PATCH.

        :return: The version of this TrustUser.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this TrustUser.
        Required when updating a user, this value should be the current version of the user.  The current version can be obtained with a GET on the user before doing a PATCH.

        :param version: The version of this TrustUser.
        :type: int
        """
        
        self._version = version

    @property
    def certifications(self):
        """
        Gets the certifications of this TrustUser.


        :return: The certifications of this TrustUser.
        :rtype: list[str]
        """
        return self._certifications

    @certifications.setter
    def certifications(self, certifications):
        """
        Sets the certifications of this TrustUser.


        :param certifications: The certifications of this TrustUser.
        :type: list[str]
        """
        
        self._certifications = certifications

    @property
    def biography(self):
        """
        Gets the biography of this TrustUser.


        :return: The biography of this TrustUser.
        :rtype: Biography
        """
        return self._biography

    @biography.setter
    def biography(self, biography):
        """
        Sets the biography of this TrustUser.


        :param biography: The biography of this TrustUser.
        :type: Biography
        """
        
        self._biography = biography

    @property
    def employer_info(self):
        """
        Gets the employer_info of this TrustUser.


        :return: The employer_info of this TrustUser.
        :rtype: EmployerInfo
        """
        return self._employer_info

    @employer_info.setter
    def employer_info(self, employer_info):
        """
        Sets the employer_info of this TrustUser.


        :param employer_info: The employer_info of this TrustUser.
        :type: EmployerInfo
        """
        
        self._employer_info = employer_info

    @property
    def routing_status(self):
        """
        Gets the routing_status of this TrustUser.
        ACD routing status

        :return: The routing_status of this TrustUser.
        :rtype: RoutingStatus
        """
        return self._routing_status

    @routing_status.setter
    def routing_status(self, routing_status):
        """
        Sets the routing_status of this TrustUser.
        ACD routing status

        :param routing_status: The routing_status of this TrustUser.
        :type: RoutingStatus
        """
        
        self._routing_status = routing_status

    @property
    def presence(self):
        """
        Gets the presence of this TrustUser.
        Active presence

        :return: The presence of this TrustUser.
        :rtype: UserPresence
        """
        return self._presence

    @presence.setter
    def presence(self, presence):
        """
        Sets the presence of this TrustUser.
        Active presence

        :param presence: The presence of this TrustUser.
        :type: UserPresence
        """
        
        self._presence = presence

    @property
    def conversation_summary(self):
        """
        Gets the conversation_summary of this TrustUser.
        Summary of conversion statistics for conversation types.

        :return: The conversation_summary of this TrustUser.
        :rtype: UserConversationSummary
        """
        return self._conversation_summary

    @conversation_summary.setter
    def conversation_summary(self, conversation_summary):
        """
        Sets the conversation_summary of this TrustUser.
        Summary of conversion statistics for conversation types.

        :param conversation_summary: The conversation_summary of this TrustUser.
        :type: UserConversationSummary
        """
        
        self._conversation_summary = conversation_summary

    @property
    def out_of_office(self):
        """
        Gets the out_of_office of this TrustUser.
        Determine if out of office is enabled

        :return: The out_of_office of this TrustUser.
        :rtype: OutOfOffice
        """
        return self._out_of_office

    @out_of_office.setter
    def out_of_office(self, out_of_office):
        """
        Sets the out_of_office of this TrustUser.
        Determine if out of office is enabled

        :param out_of_office: The out_of_office of this TrustUser.
        :type: OutOfOffice
        """
        
        self._out_of_office = out_of_office

    @property
    def geolocation(self):
        """
        Gets the geolocation of this TrustUser.
        Current geolocation position

        :return: The geolocation of this TrustUser.
        :rtype: Geolocation
        """
        return self._geolocation

    @geolocation.setter
    def geolocation(self, geolocation):
        """
        Sets the geolocation of this TrustUser.
        Current geolocation position

        :param geolocation: The geolocation of this TrustUser.
        :type: Geolocation
        """
        
        self._geolocation = geolocation

    @property
    def station(self):
        """
        Gets the station of this TrustUser.
        Effective, default, and last station information

        :return: The station of this TrustUser.
        :rtype: UserStations
        """
        return self._station

    @station.setter
    def station(self, station):
        """
        Sets the station of this TrustUser.
        Effective, default, and last station information

        :param station: The station of this TrustUser.
        :type: UserStations
        """
        
        self._station = station

    @property
    def authorization(self):
        """
        Gets the authorization of this TrustUser.
        Roles and permissions assigned to the user

        :return: The authorization of this TrustUser.
        :rtype: UserAuthorization
        """
        return self._authorization

    @authorization.setter
    def authorization(self, authorization):
        """
        Sets the authorization of this TrustUser.
        Roles and permissions assigned to the user

        :param authorization: The authorization of this TrustUser.
        :type: UserAuthorization
        """
        
        self._authorization = authorization

    @property
    def profile_skills(self):
        """
        Gets the profile_skills of this TrustUser.
        Profile skills possessed by the user

        :return: The profile_skills of this TrustUser.
        :rtype: list[str]
        """
        return self._profile_skills

    @profile_skills.setter
    def profile_skills(self, profile_skills):
        """
        Sets the profile_skills of this TrustUser.
        Profile skills possessed by the user

        :param profile_skills: The profile_skills of this TrustUser.
        :type: list[str]
        """
        
        self._profile_skills = profile_skills

    @property
    def locations(self):
        """
        Gets the locations of this TrustUser.
        The user placement at each site location.

        :return: The locations of this TrustUser.
        :rtype: list[Location]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """
        Sets the locations of this TrustUser.
        The user placement at each site location.

        :param locations: The locations of this TrustUser.
        :type: list[Location]
        """
        
        self._locations = locations

    @property
    def groups(self):
        """
        Gets the groups of this TrustUser.
        The groups the user is a member of

        :return: The groups of this TrustUser.
        :rtype: list[Group]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """
        Sets the groups of this TrustUser.
        The groups the user is a member of

        :param groups: The groups of this TrustUser.
        :type: list[Group]
        """
        
        self._groups = groups

    @property
    def team(self):
        """
        Gets the team of this TrustUser.
        The team the user is a member of

        :return: The team of this TrustUser.
        :rtype: Team
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this TrustUser.
        The team the user is a member of

        :param team: The team of this TrustUser.
        :type: Team
        """
        
        self._team = team

    @property
    def skills(self):
        """
        Gets the skills of this TrustUser.
        Routing (ACD) skills possessed by the user

        :return: The skills of this TrustUser.
        :rtype: list[UserRoutingSkill]
        """
        return self._skills

    @skills.setter
    def skills(self, skills):
        """
        Sets the skills of this TrustUser.
        Routing (ACD) skills possessed by the user

        :param skills: The skills of this TrustUser.
        :type: list[UserRoutingSkill]
        """
        
        self._skills = skills

    @property
    def languages(self):
        """
        Gets the languages of this TrustUser.
        Routing (ACD) languages possessed by the user

        :return: The languages of this TrustUser.
        :rtype: list[UserRoutingLanguage]
        """
        return self._languages

    @languages.setter
    def languages(self, languages):
        """
        Sets the languages of this TrustUser.
        Routing (ACD) languages possessed by the user

        :param languages: The languages of this TrustUser.
        :type: list[UserRoutingLanguage]
        """
        
        self._languages = languages

    @property
    def acd_auto_answer(self):
        """
        Gets the acd_auto_answer of this TrustUser.
        acd auto answer

        :return: The acd_auto_answer of this TrustUser.
        :rtype: bool
        """
        return self._acd_auto_answer

    @acd_auto_answer.setter
    def acd_auto_answer(self, acd_auto_answer):
        """
        Sets the acd_auto_answer of this TrustUser.
        acd auto answer

        :param acd_auto_answer: The acd_auto_answer of this TrustUser.
        :type: bool
        """
        
        self._acd_auto_answer = acd_auto_answer

    @property
    def language_preference(self):
        """
        Gets the language_preference of this TrustUser.
        preferred language by the user

        :return: The language_preference of this TrustUser.
        :rtype: str
        """
        return self._language_preference

    @language_preference.setter
    def language_preference(self, language_preference):
        """
        Sets the language_preference of this TrustUser.
        preferred language by the user

        :param language_preference: The language_preference of this TrustUser.
        :type: str
        """
        
        self._language_preference = language_preference

    @property
    def last_token_issued(self):
        """
        Gets the last_token_issued of this TrustUser.


        :return: The last_token_issued of this TrustUser.
        :rtype: OAuthLastTokenIssued
        """
        return self._last_token_issued

    @last_token_issued.setter
    def last_token_issued(self, last_token_issued):
        """
        Sets the last_token_issued of this TrustUser.


        :param last_token_issued: The last_token_issued of this TrustUser.
        :type: OAuthLastTokenIssued
        """
        
        self._last_token_issued = last_token_issued

    @property
    def trust_user_details(self):
        """
        Gets the trust_user_details of this TrustUser.


        :return: The trust_user_details of this TrustUser.
        :rtype: TrustUserDetails
        """
        return self._trust_user_details

    @trust_user_details.setter
    def trust_user_details(self, trust_user_details):
        """
        Sets the trust_user_details of this TrustUser.


        :param trust_user_details: The trust_user_details of this TrustUser.
        :type: TrustUserDetails
        """
        
        self._trust_user_details = trust_user_details

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SipSearchResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SipSearchResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'status': 'int',
            'sid': 'str',
            'auth': 'str',
            'message': 'str',
            'data': 'list[HomerRecord]',
            'count': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'status': 'status',
            'sid': 'sid',
            'auth': 'auth',
            'message': 'message',
            'data': 'data',
            'count': 'count',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._status = None
        self._sid = None
        self._auth = None
        self._message = None
        self._data = None
        self._count = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this SipSearchResult.
        The globally unique identifier for the object.

        :return: The id of this SipSearchResult.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SipSearchResult.
        The globally unique identifier for the object.

        :param id: The id of this SipSearchResult.
        :type: str
        """
        
        self._id = id

    @property
    def status(self):
        """
        Gets the status of this SipSearchResult.
        Status of the search request

        :return: The status of this SipSearchResult.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this SipSearchResult.
        Status of the search request

        :param status: The status of this SipSearchResult.
        :type: int
        """
        
        self._status = status

    @property
    def sid(self):
        """
        Gets the sid of this SipSearchResult.
        Session id associated to the search request

        :return: The sid of this SipSearchResult.
        :rtype: str
        """
        return self._sid

    @sid.setter
    def sid(self, sid):
        """
        Sets the sid of this SipSearchResult.
        Session id associated to the search request

        :param sid: The sid of this SipSearchResult.
        :type: str
        """
        
        self._sid = sid

    @property
    def auth(self):
        """
        Gets the auth of this SipSearchResult.
        Auth token used for this search request

        :return: The auth of this SipSearchResult.
        :rtype: str
        """
        return self._auth

    @auth.setter
    def auth(self, auth):
        """
        Sets the auth of this SipSearchResult.
        Auth token used for this search request

        :param auth: The auth of this SipSearchResult.
        :type: str
        """
        
        self._auth = auth

    @property
    def message(self):
        """
        Gets the message of this SipSearchResult.
        Any messages returned from homer as part of the response

        :return: The message of this SipSearchResult.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this SipSearchResult.
        Any messages returned from homer as part of the response

        :param message: The message of this SipSearchResult.
        :type: str
        """
        
        self._message = message

    @property
    def data(self):
        """
        Gets the data of this SipSearchResult.
        Homer search data that is returned

        :return: The data of this SipSearchResult.
        :rtype: list[HomerRecord]
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this SipSearchResult.
        Homer search data that is returned

        :param data: The data of this SipSearchResult.
        :type: list[HomerRecord]
        """
        
        self._data = data

    @property
    def count(self):
        """
        Gets the count of this SipSearchResult.
        Number of records returned

        :return: The count of this SipSearchResult.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this SipSearchResult.
        Number of records returned

        :param count: The count of this SipSearchResult.
        :type: int
        """
        
        self._count = count

    @property
    def self_uri(self):
        """
        Gets the self_uri of this SipSearchResult.
        The URI for this object

        :return: The self_uri of this SipSearchResult.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this SipSearchResult.
        The URI for this object

        :param self_uri: The self_uri of this SipSearchResult.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CreateEmailRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateEmailRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'queue_id': 'str',
            'flow_id': 'str',
            'provider': 'str',
            'skill_ids': 'list[str]',
            'language_id': 'str',
            'priority': 'int',
            'attributes': 'dict(str, str)',
            'to_address': 'str',
            'to_name': 'str',
            'from_address': 'str',
            'from_name': 'str',
            'subject': 'str',
            'direction': 'str',
            'html_body': 'str',
            'text_body': 'str'
        }

        self.attribute_map = {
            'queue_id': 'queueId',
            'flow_id': 'flowId',
            'provider': 'provider',
            'skill_ids': 'skillIds',
            'language_id': 'languageId',
            'priority': 'priority',
            'attributes': 'attributes',
            'to_address': 'toAddress',
            'to_name': 'toName',
            'from_address': 'fromAddress',
            'from_name': 'fromName',
            'subject': 'subject',
            'direction': 'direction',
            'html_body': 'htmlBody',
            'text_body': 'textBody'
        }

        self._queue_id = None
        self._flow_id = None
        self._provider = None
        self._skill_ids = None
        self._language_id = None
        self._priority = None
        self._attributes = None
        self._to_address = None
        self._to_name = None
        self._from_address = None
        self._from_name = None
        self._subject = None
        self._direction = None
        self._html_body = None
        self._text_body = None

    @property
    def queue_id(self):
        """
        Gets the queue_id of this CreateEmailRequest.
        The ID of the queue to use for routing the email conversation. This field is mutually exclusive with flowId

        :return: The queue_id of this CreateEmailRequest.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this CreateEmailRequest.
        The ID of the queue to use for routing the email conversation. This field is mutually exclusive with flowId

        :param queue_id: The queue_id of this CreateEmailRequest.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def flow_id(self):
        """
        Gets the flow_id of this CreateEmailRequest.
        The ID of the flow to use for routing email conversation. This field is mutually exclusive with queueId

        :return: The flow_id of this CreateEmailRequest.
        :rtype: str
        """
        return self._flow_id

    @flow_id.setter
    def flow_id(self, flow_id):
        """
        Sets the flow_id of this CreateEmailRequest.
        The ID of the flow to use for routing email conversation. This field is mutually exclusive with queueId

        :param flow_id: The flow_id of this CreateEmailRequest.
        :type: str
        """
        
        self._flow_id = flow_id

    @property
    def provider(self):
        """
        Gets the provider of this CreateEmailRequest.
        The name of the provider that is sourcing the emails. The Provider \"PureCloud Email\" is reserved for native emails.

        :return: The provider of this CreateEmailRequest.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this CreateEmailRequest.
        The name of the provider that is sourcing the emails. The Provider \"PureCloud Email\" is reserved for native emails.

        :param provider: The provider of this CreateEmailRequest.
        :type: str
        """
        
        self._provider = provider

    @property
    def skill_ids(self):
        """
        Gets the skill_ids of this CreateEmailRequest.
        The list of skill ID's to use for routing.

        :return: The skill_ids of this CreateEmailRequest.
        :rtype: list[str]
        """
        return self._skill_ids

    @skill_ids.setter
    def skill_ids(self, skill_ids):
        """
        Sets the skill_ids of this CreateEmailRequest.
        The list of skill ID's to use for routing.

        :param skill_ids: The skill_ids of this CreateEmailRequest.
        :type: list[str]
        """
        
        self._skill_ids = skill_ids

    @property
    def language_id(self):
        """
        Gets the language_id of this CreateEmailRequest.
        The ID of the language to use for routing.

        :return: The language_id of this CreateEmailRequest.
        :rtype: str
        """
        return self._language_id

    @language_id.setter
    def language_id(self, language_id):
        """
        Sets the language_id of this CreateEmailRequest.
        The ID of the language to use for routing.

        :param language_id: The language_id of this CreateEmailRequest.
        :type: str
        """
        
        self._language_id = language_id

    @property
    def priority(self):
        """
        Gets the priority of this CreateEmailRequest.
        The priority to assign to the conversation for routing.

        :return: The priority of this CreateEmailRequest.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this CreateEmailRequest.
        The priority to assign to the conversation for routing.

        :param priority: The priority of this CreateEmailRequest.
        :type: int
        """
        
        self._priority = priority

    @property
    def attributes(self):
        """
        Gets the attributes of this CreateEmailRequest.
        The list of attributes to associate with the customer participant.

        :return: The attributes of this CreateEmailRequest.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this CreateEmailRequest.
        The list of attributes to associate with the customer participant.

        :param attributes: The attributes of this CreateEmailRequest.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def to_address(self):
        """
        Gets the to_address of this CreateEmailRequest.
        The email address of the recipient of the email.

        :return: The to_address of this CreateEmailRequest.
        :rtype: str
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """
        Sets the to_address of this CreateEmailRequest.
        The email address of the recipient of the email.

        :param to_address: The to_address of this CreateEmailRequest.
        :type: str
        """
        
        self._to_address = to_address

    @property
    def to_name(self):
        """
        Gets the to_name of this CreateEmailRequest.
        The name of the recipient of the email.

        :return: The to_name of this CreateEmailRequest.
        :rtype: str
        """
        return self._to_name

    @to_name.setter
    def to_name(self, to_name):
        """
        Sets the to_name of this CreateEmailRequest.
        The name of the recipient of the email.

        :param to_name: The to_name of this CreateEmailRequest.
        :type: str
        """
        
        self._to_name = to_name

    @property
    def from_address(self):
        """
        Gets the from_address of this CreateEmailRequest.
        The email address of the sender of the email.

        :return: The from_address of this CreateEmailRequest.
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """
        Sets the from_address of this CreateEmailRequest.
        The email address of the sender of the email.

        :param from_address: The from_address of this CreateEmailRequest.
        :type: str
        """
        
        self._from_address = from_address

    @property
    def from_name(self):
        """
        Gets the from_name of this CreateEmailRequest.
        The name of the sender of the email.

        :return: The from_name of this CreateEmailRequest.
        :rtype: str
        """
        return self._from_name

    @from_name.setter
    def from_name(self, from_name):
        """
        Sets the from_name of this CreateEmailRequest.
        The name of the sender of the email.

        :param from_name: The from_name of this CreateEmailRequest.
        :type: str
        """
        
        self._from_name = from_name

    @property
    def subject(self):
        """
        Gets the subject of this CreateEmailRequest.
        The subject of the email

        :return: The subject of this CreateEmailRequest.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this CreateEmailRequest.
        The subject of the email

        :param subject: The subject of this CreateEmailRequest.
        :type: str
        """
        
        self._subject = subject

    @property
    def direction(self):
        """
        Gets the direction of this CreateEmailRequest.
        Specify OUTBOUND to send an email on behalf of a queue, or INBOUND to create an external conversation. An external conversation is one where the provider is not PureCloud based.

        :return: The direction of this CreateEmailRequest.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this CreateEmailRequest.
        Specify OUTBOUND to send an email on behalf of a queue, or INBOUND to create an external conversation. An external conversation is one where the provider is not PureCloud based.

        :param direction: The direction of this CreateEmailRequest.
        :type: str
        """
        allowed_values = ["OUTBOUND", "INBOUND"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def html_body(self):
        """
        Gets the html_body of this CreateEmailRequest.
        An HTML body content of the email.

        :return: The html_body of this CreateEmailRequest.
        :rtype: str
        """
        return self._html_body

    @html_body.setter
    def html_body(self, html_body):
        """
        Sets the html_body of this CreateEmailRequest.
        An HTML body content of the email.

        :param html_body: The html_body of this CreateEmailRequest.
        :type: str
        """
        
        self._html_body = html_body

    @property
    def text_body(self):
        """
        Gets the text_body of this CreateEmailRequest.
        A text body content of the email.

        :return: The text_body of this CreateEmailRequest.
        :rtype: str
        """
        return self._text_body

    @text_body.setter
    def text_body(self, text_body):
        """
        Sets the text_body of this CreateEmailRequest.
        A text body content of the email.

        :param text_body: The text_body of this CreateEmailRequest.
        :type: str
        """
        
        self._text_body = text_body

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

